/*
 * Copyright 201=9 Rockchip Electronics S.LSI Co. LTD
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

#ifndef __ROCKCHIP_DRM_H__
#define __ROCKCHIP_DRM_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <linux/videodev2.h>

#define DRM_ALIGN(x, a)         (((x) + (a) - 1) / (a) * (a))

#define V4L2_PIX_FMT_NV12_10LE40	v4l2_fourcc('N', 'A', '1', '2') /* Y/CbCr :4:2:0 10bit */
#define V4L2_PIX_FMT_NV21_10LE40	v4l2_fourcc('N', 'A', '2', '1') /* Y/CrCb :4:2:0 10bit */
#define V4L2_PIX_FMT_NV16_10LE40	v4l2_fourcc('N', 'A', '1', '6') /* Y/CbCr :4:2:2 10bit */
#define V4L2_PIX_FMT_NV61_10LE40	v4l2_fourcc('N', 'A', '6', '1') /* Y/CrCb :4:2:2 10bit */

/**
 * DrmBuffer - Drm buffer allocated by drm interface.
 * @fd: drm buffer file descriptor
 * @handle: drm buffer handle
 * @virt: drm buffer virtual address
 * @size: frame size
 * @size_align: size with 16byte-align
 * @phys: cma buffer physical address
 */ 
typedef struct _DrmBuffer {
    int fd;
    unsigned int handle;
    void *virt;
    size_t size;
    size_t size_align;
    unsigned long phys;
} DrmBuffer;

int RockchipDrmOpen();
void RockchipDrmClose(int fd);

/* Drm Memory Allocator: physical address is non-contiguous */
DrmBuffer *RockchipDrmAlloc(int fd, __u32 v4l2Format, __u32 width, __u32 height);
void RockchipDrmFree(int fd, DrmBuffer *buf);

/* Contiguous Memory Allocator: physical address is contiguous */
DrmBuffer *RockchipCmaAlloc(int fd,  __u32 v4l2Format, __u32 width, __u32 height);
DrmBuffer *RockchipCmaAlloc1(int fd,  size_t size);
void RockchipCmaFree(int fd, DrmBuffer *buf);

#ifdef __cplusplus
}
#endif

#endif
